@@ -30,6 +30,7 @@
 
 #include <QtCore/QDebug>
 #include <QtCore/QMap>
+#include <QtCore/QRegExp>
 #include <QtCore/QStack>
 #include <QtCore/QString>
 #include <QtCore/QTextCodec>
@@ -759,7 +760,7 @@ bool saveXLIFF(const Translator &translator, QIODevice &dev, ConversionData &cd)
 
     QStringList dtgs = cd.dropTags();
     dtgs << QLatin1String("po-(old_)?msgid_plural");
-    QRegExp drops(dtgs.join(QLatin1String("|")));
+    QRegExp drops(dtgs.join(QLatin1Char('|')));
 
     QHash<QString, QHash<QString, QList<TranslatorMessage> > > messageOrder;
     QHash<QString, QList<QString> > contextOrder;
@@ -833,7 +834,7 @@ int initXLIFF()
 {
     Translator::FileFormat format;
     format.extension = QLatin1String("xlf");
-    format.description = FMT::tr("XLIFF localization files");
+    format.untranslatedDescription = QT_TRANSLATE_NOOP("FMT", "XLIFF localization files");
     format.fileType = Translator::FileFormat::TranslationSource;
     format.priority = 1;
     format.loader = &loadXLIFF;
